@@ -17,7 +17,7 @@ class FileList:
 
 	def __init__(self, dir, filter = "*", exclude = ""):
 		self.__list = []
-		self.__dir = dir
+		self.__dir = os.path.abspath(dir)
 		self.__filter = ""
 
 
