@@ -1,6 +1,11 @@
 #!/usr/bin/env python
 # -*- coding: utf8 -*-
 
+import platform
+
+if platform.system() == 'Windows':
+    from compat import *
+
 from puke.Error import *
 from puke.Task  import *
 from puke.Tools  import *
